#ifndef CONTROLLERPARK_H
#define CONTROLLERPARK_H

#include "controller.h"
#include "carobject.h"


#define MAXPADS 4
#define MAXCONTROLLERS (MAXPADS+1)	// Add 1 for keyboard control


class ControllerPark
{
  public:
    ControllerPark(bool include_keyboard=true) :
    padCount(0),
    controllerCount(0),
    key(0)
    {
      int i;
      for (i=0; i<MAXCONTROLLERS; i++)
        cars[i]=0;
      for (i=0; i<MAXPADS; i++)
      {
        char devname[80];
        sprintf(devname,"/dev/input/js%d", i);
        ControllerPad *pad = new ControllerPad(devname);
        assert(pad);
        if (pad->IsWorking())
        {
          pads[padCount] = pad;
          controllers[controllerCount] = pad;
          padCount++;
          controllerCount++;
        }
      }
      if (include_keyboard) 
      {
        key = new ControllerKey();
        controllers[controllerCount++] = key;
      }
      fprintf(stderr,"We have %s keyboard controller, and %d gamepad controllers\n", (key)?"a":"no", padCount);
    }
    ~ControllerPark()
    {
      for (int i=0; i<padCount; i++)
        delete pads[i];
      delete key;
    }
    void Sustain(float dt)
    {
      for (int i=0; i<controllerCount; i++)
      {
        controllers[i]->Sustain(dt);
        if (cars[i])
        {
          float ste = controllers[i]->GetSteer();
          float acc = controllers[i]->GetAccel();
          float bra = controllers[i]->GetBrake();
          bool  act = controllers[i]->GetButtonValue(0);
          bool  ebr = controllers[i]->GetButtonValue(1);
          cars[i]->SetSteer(ste);
          cars[i]->SetAccelerator(acc);
          cars[i]->SetBrake(bra);
          cars[i]->SetAction(act);
          cars[i]->SetEBrake(ebr);
        }
      }
    }
    void Associate(int nr, CarObject *car)
    {
      assert(nr < controllerCount);
      cars[nr] = car;
    }
    void Feed(unsigned char k, bool down)
    {
      if (key) key->Feed(k,down);
    }
    int GetNumControllers(void) { return controllerCount; }

  protected:
    int padCount;
    int controllerCount;
    Controller *controllers[MAXCONTROLLERS];
    CarObject  *cars[MAXCONTROLLERS];
    ControllerPad *pads[MAXPADS];
    ControllerKey *key;
};

#endif

